#include "save/skillsDB.hpp"
#include <iostream>
#include <algorithm>

namespace editor::save::skills
{
    std::map<uint16_t, SkillsDBEntry> skillsDatabase;
    std::vector<SkillsDBEntry> skillList;

    std::string SkillsDB::getName(uint16_t id) {
        if ( skillsDatabase.find(id) != skillsDatabase.end() ) {
            auto demonEntry = skillsDatabase.at(id);
            return demonEntry.name;
        } else {
            return std::string("#! Unknown please report this as a Github Issue! ID: ") + std::to_string(id);
        }
    }

    SkillsDBEntry SkillsDB::getEntry(uint16_t id) {
        if ( skillsDatabase.find(id) != skillsDatabase.end() ) {
            auto demonEntry = skillsDatabase.at(id);
            return demonEntry;
        } else {
            return skillsDatabase.at(0);
        }
    }

    SkillsDB::SkillsDB() {

        if (skillsDatabase.size() > 0) {
            // No need to initialise
            return;
        }

        // The skills list vector is created below this monstrosity

        // so lets just agree to ignore this and the fact it belongs in a json file.....
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0, {0x0, "None"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01, {0x01, "Agi"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x03, {0x03, "Agilao"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x05, {0x05, "Agidyne"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x07, {0x07, "Agibarion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x08, {0x08, "Trisagion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x09, {0x09, "Maragi"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0A, {0x0A, "Maragion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0B, {0x0B, "Maragidyne"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0C, {0x0C, "Maragibarion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0D, {0x0D, "Ragnarok"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0E, {0x0E, "FireBreath"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x10, {0x10, "Bufu"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x12, {0x12, "Bufula"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x14, {0x14, "Bufudyne"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x16, {0x16, "Bufubarion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x17, {0x17, "Ice Age"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x18, {0x18, "Mabufu"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x19, {0x19, "Mabufula"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x1A, {0x1A, "Mabufudyne"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x1B, {0x1B, "Mabufubarion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x1C, {0x1C, "Glacial Blast"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x1D, {0x1D, "Ice Breath"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x1F, {0x1F, "Zio"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x21, {0x21, "Zionga"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x23, {0x23, "Ziodyne"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x25, {0x25, "Ziobarion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x26, {0x26, "Narukami"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x27, {0x27, "Mazio"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x28, {0x28, "Mazionga"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x29, {0x29, "Maziodyne"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x2A, {0x2A, "Maziobarion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x2B, {0x2B, "Thunder Reign"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x2C, {0x2C, "Shockbound"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x2E, {0x2E, "Zan"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x30, {0x30, "Zanma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x32, {0x32, "Zandyne"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x34, {0x34, "Zanbarion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x35, {0x35, "Killing Wind"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x36, {0x36, "Mazan"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x37, {0x37, "Mazanma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x38, {0x38, "Mazandyne"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x39, {0x39, "Mazanbarion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x3A, {0x3A, "Floral Gust"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x3B, {0x3B, "Wind Breath"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x3C, {0x3C, "Omagatoki Critical"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x3D, {0x3D, "Mudo"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x3E, {0x3E, "Mudoon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x3F, {0x3F, "Mudobarion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x40, {0x40, "Mamudo"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x41, {0x41, "Mamudoon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x42, {0x42, "Mamudobarion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x43, {0x43, "Hama"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x44, {0x44, "Hamaon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x45, {0x45, "Hamabarion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x46, {0x46, "Mahama"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x47, {0x47, "Mahamaon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x48, {0x48, "Mahamabarion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x49, {0x49, "Megido"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x4A, {0x4A, "Megidola"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x4B, {0x4B, "Megidolaon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x4C, {0x4C, "Big Bang"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x4D, {0x4D, "Freikugel"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x4E, {0x4E, "Freikugel EX"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x4F, {0x4F, "Life Drain"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x50, {0x50, "Spirit Drain"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x51, {0x51, "Energy Drain"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x52, {0x52, "Slumber Vortex"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x53, {0x53, "Dormina"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x54, {0x54, "Lullaby"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x55, {0x55, "Poisoma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x56, {0x56, "Toxic Cloud"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x57, {0x57, "Soul Drain"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x58, {0x58, "Lightning Pulse"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x59, {0x59, "Pulinpa"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x5A, {0x5A, "Tentarafoo"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x5B, {0x5B, "Marin Karin"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x5C, {0x5C, "Sexy Dance"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x5D, {0x5D, "Makajama"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x5E, {0x5E, "Makajamaon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x5F, {0x5F, "Dustoma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x60, {0x60, "Fogna"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x61, {0x61, "Dia"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x62, {0x62, "Diarama"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x63, {0x63, "Diarahan"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x64, {0x64, "Media"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x65, {0x65, "Mediarama"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x66, {0x66, "Mediarahan"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x67, {0x67, "Dia"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x68, {0x68, "Diawama"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x69, {0x69, "Media"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x6A, {0x6A, "Mediarama"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x6B, {0x6B, "Patra"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x6C, {0x6C, "Me Patra"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x6D, {0x6D, "Twilight Wave"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x6E, {0x6E, "Eternal Prayer"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x6F, {0x6F, "Sea of Stars"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x70, {0x70, "Waters of Youth"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x71, {0x71, "Accursed Poison"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x72, {0x72, "Rasetsu Feast"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x73, {0x73, "Recarm"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x74, {0x74, "Samarecarm"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x75, {0x75, "Heavenly Counter"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x76, {0x76, "Tarukaja"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x77, {0x77, "Matarukaja"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x78, {0x78, "Fairy Banquet"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x79, {0x79, "Expand Critical Aura"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x7A, {0x7A, "Sukukaja"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x7B, {0x7B, "Masukukaja"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x7C, {0x7C, "Rakukaja"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x7D, {0x7D, "Marakukaja"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x7E, {0x7E, "Luster Candy"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x7F, {0x7F, "Dekaja"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x80, {0x80, "Tarunda"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x81, {0x81, "Matarunda"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x82, {0x82, "Shield of God"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x83, {0x83, "Expand Piercing Aura"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x84, {0x84, "Sukunda"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x85, {0x85, "Masukunda"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x86, {0x86, "Rakunda"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x87, {0x87, "Marakunda"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x88, {0x88, "Debilitate"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x89, {0x89, "Dekunda"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x8A, {0x8A, "Impalaers Glory"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x8B, {0x8B, "Tetrakarn"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x8C, {0x8C, "Makarakarn"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x8D, {0x8D, "Charge"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x8F, {0x8F, "Concentrate"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x90, {0x90, "Critical Aura"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x91, {0x91, "Dekajaon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x92, {0x92, "Omagatoki Pierce"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x93, {0x93, "Omagaroki Hit"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x94, {0x94, "Impalaers Animus"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x95, {0x95, "Bowl of Hygieia"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x96, {0x96, "Diamrita"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x9A, {0x9A, "Trafuri"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x9B, {0x9B, "Estoma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x9C, {0x9C, "Escape"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x9D, {0x9D, "Lunge"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x9E, {0x9E, "Berserker God"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x9F, {0x9F, "Mortal Jihad"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xA0, {0xA0, "Akashic Arts"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xA1, {0xA1, "Heat Wave"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xA2, {0xA2, "Deathbound"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xA3, {0xA3, "Hades Blast"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xA4, {0xA4, "Brave Blade"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xA5, {0xA5, "Heavy Blow"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xA6, {0xA6, "Hell Thrust"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xA7, {0xA7, "Critical Wave"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xA8, {0xA8, "Titanomachia"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xA9, {0xA9, "Beatdown"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xAA, {0xAA, "Power Punch"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xAB, {0xAB, "Fang Breaker"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xAC, {0xAC, "Puncture Punch"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xAD, {0xAD, "Pierce Armor"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xAE, {0xAE, "Blinding Strike"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xAF, {0xAF, "Dream Fist"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xB0, {0xB0, "Purple Smoke"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xB1, {0xB1, "Omagatoki Adversity"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xB2, {0xB2, "Fire Dracostrike"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xB3, {0xB3, "Ice Dracostrike"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xB4, {0xB4, "Storm Dracostrike"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xB5, {0xB5, "Wind Dracostrike"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xB6, {0xB6, "Hysterical Slap"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xB7, {0xB7, "Gram Slice"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xB8, {0xB8, "Fatal Sword"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xB9, {0xB9, "Myriad Slashes"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xBA, {0xBA, "Blight"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xBB, {0xBB, "Omagatoki Free"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xBC, {0xBC, "Dark Sword"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xBD, {0xBD, "Mist Rush"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xBE, {0xBE, "Counter"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xBF, {0xBF, "Retaliate"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xC0, {0xC0, "Catastrophe"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xC1, {0xC1, "Omagatoki Doubler"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xC2, {0xC2, "Figment Slash"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xC3, {0xC3, "Bouncing Claw"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xC4, {0xC4, "Damascus Claw"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xC5, {0xC5, "Nihil Claw"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xC6, {0xC6, "Scratch Dance "}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xC7, {0xC7, "Axel Claw"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xC8, {0xC8, "Madness Nails"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xC9, {0xC9, "Omagatoki Dance"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xCA, {0xCA, "Venom Chaser"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xCB, {0xCB, "Bestial Bite"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xCC, {0xCC, "Severing Bite"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xCD, {0xCD, "Frenzied Chomp"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xCE, {0xCE, "Eat Whole"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xCF, {0xCF, "Dream Needle"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xD0, {0xD0, "Toxic Sting"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xD1, {0xD1, "Needle Spray"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xD2, {0xD2, "Madness Needle"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xD3, {0xD3, "Yabusame Shot"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xD4, {0xD4, "Steel Needle"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xD5, {0xD5, "Crusher Onslaught"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xD6, {0xD6, "Megaton Press"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xD7, {0xD7, "Omagatoki Sincerity"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xD8, {0xD8, "Rampage"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xD9, {0xD9, "Die For Me"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xDA, {0xDA, "King Bufula"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xDB, {0xDB, "Eternal Blizzard"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xDC, {0xDC, "Jack Bufula"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xDD, {0xDD, "Hellish Brand"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xDE, {0xDE, "Raging Hellfire"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xDF, {0xDF, "Raging Blizzard"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xE0, {0xE0, "Raginf Lightning"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xE1, {0xE1, "Raging Tempest"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xE2, {0xE2, "Fire of Sinai"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xE3, {0xE3, "Mac an Luin"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xE4, {0xE4, "Babylon Goblet"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xE5, {0xE5, "Frolic"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xE6, {0xE6, "Cautious Cheer"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xE7, {0xE7, "Ghastfire Rain"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xE8, {0xE8, "Gungnir"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xE9, {0xE9, "Hassou Tobi"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xEA, {0xEA, "Andalucia"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xEB, {0xEB, "Terrorblade"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xEC, {0xEC, "Pestilience"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xED, {0xED, "Gods Bow"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xEE, {0xEE, "Soul Divide"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xEF, {0xEF, "Evil Melody"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xF0, {0xF0, "Mesektets Path"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xF2, {0xF2, "Critical Slash"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xF3, {0xF3, "Might Cleave"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xF4, {0xF4, "Black Dracostrike"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xF5, {0xF5, "White Dracostrike"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xF6, {0xF6, "Donum Gladi"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xF7, {0xF7, "Donum Magici"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xF8, {0xF8, "Taunt"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xF9, {0xF9, "Omagatoki Savage"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xFA, {0xFA, "Toxic Spray"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xFB, {0xFB, "Scouffle Declair"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xFC, {0xFC, "Hellish Slash"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xFD, {0xFD, "Harvest Dance"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xFE, {0xFE, "Mirage Shot"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0xFF, {0xFF, "Moonlight Frost"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0100, {0x0100, "Stormcaller Song"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0101, {0x0101, "Karnak"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0102, {0x0102, "Acrobat Kick"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0103, {0x0103, "Helioplis Dawn"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0104, {0x0104, "Fierce Roar"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0105, {0x0105, "Tandava"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0106, {0x0106, "Hellish Spurt"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0107, {0x0107, "Megido Flame"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0108, {0x0108, "Walpurgisnacht"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0109, {0x0109, "Carnage Fang"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x010A, {0x010A, "Suns Radiance"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x010B, {0x010B, "Witness Me"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x010C, {0x010C, "Hell Spin"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x010D, {0x010D, "Light Descent"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x010E, {0x010E, "Fallen Destroyer"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x010F, {0x010F, "Sanguin Drain"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0110, {0x0110, "Dancing Strike"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0111, {0x0111, "Sacrifice Clay"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0112, {0x0112, "Omagatoki Luck"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0113, {0x0113, "Preach"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0114, {0x0114, "Golden Apple"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0115, {0x0115, "Matriarchs Love"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0116, {0x0116, "Red Capote"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0117, {0x0117, "Matriarchs Love"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0118, {0x0118, "Humble Blessing"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0119, {0x0119, "Eleusinian Harvest"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x011A, {0x011A, "Keraunos"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x011B, {0x011B, "Frenzy"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x011C, {0x011C, "Galvanic Slah"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x011D, {0x011D, "Electrify"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x011E, {0x011E, "Rising Storm Dragon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x011F, {0x011F, "Attack"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0120, {0x0120, "Charge"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0121, {0x0121, "Babylon Curse"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0123, {0x0123, "Silt of Ruin"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0124, {0x0124, "Sakanagi"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0125, {0x0125, "Divine Arrowfall"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0126, {0x0126, "Murakumo"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0127, {0x0127, "Red Capote"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0128, {0x0128, "meditation"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0129, {0x0129, "Hell Burner"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x012A, {0x012A, "Aramasa"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x012B, {0x012B, "Wrath Tempest"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x012C, {0x012C, "Ruinous Thunder"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x012D, {0x012D, "Thalassic Calamity"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x012E, {0x012E, "Hell Exhaust"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x012F, {0x012F, "Death Lust"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0130, {0x0130, "Headcrush"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0131, {0x0131, "Somersault"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0132, {0x0132, "Kannabi Veil"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0133, {0x0133, "Profaned Land"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0134, {0x0134, "Stagnat Air"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0135, {0x0135, "Omagatoki Potential"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0136, {0x0136, "Miracle Water"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0137, {0x0137, "Revival Chant"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0138, {0x0138, "Dreadful Gleam"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0139, {0x0139, "Dreadful Gleam"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x013A, {0x013A, "Harvest Dance"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x013B, {0x013B, "Toxic Breath"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x013C, {0x013C, "Call Angels"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x013D, {0x013D, "Call Soldier"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x013E, {0x013E, "Call Souls"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x013F, {0x013F, "Call Evil"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0140, {0x0140, "Purgatorium"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0141, {0x0141, "Impetus"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0142, {0x0142, "Mesektets Path"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0145, {0x0145, "Death Flies"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0146, {0x0146, "Light of Order"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0148, {0x0148, "Astral Saintstrike"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0149, {0x0149, "Inferno of God"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x014A, {0x014A, "Hailstorm of God"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x014B, {0x014B, "Lightning of God"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x014C, {0x014C, "Tornado of God"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x014D, {0x014D, "Cold Dark Matter"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x014E, {0x014E, "Hot Dark Matter"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x014F, {0x014F, "Freikugel"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0150, {0x0150, "Gaea Rage"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0151, {0x0151, "Magma Axis"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0152, {0x0152, "Javelin Rain "}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0153, {0x0153, "Xeros Beat"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0154, {0x0154, "Deadly Fury"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0155, {0x0155, "Wild Dance"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0156, {0x0156, "Contempt of God"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0157, {0x0157, "Holy Cruxifixion"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0159, {0x0159, "Omagatoki Charge"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x015B, {0x015B, "Falling Star Fire"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x015C, {0x015C, "Falling Star Ice"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x015D, {0x015D, "Morning Star"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0160, {0x0160, "Dia"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0161, {0x0161, "Diarama"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0162, {0x0162, "Media"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0163, {0x0163, "Mediarama"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0164, {0x0164, "Electrify"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0165, {0x0165, "True Replication"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0166, {0x0166, "False Replication"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0167, {0x0167, "Rising Storm Dragon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0168, {0x0168, "Rising Storm Dragon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0169, {0x0169, "Rising Storm Dragon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x016A, {0x016A, "Rising Storm Dragon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x016B, {0x016B, "Phys Block"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x016C, {0x016C, "Fire Block"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x016D, {0x016D, "Ice Block"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x016E, {0x016E, "Elec Block"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x016F, {0x016F, "Force Block"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0170, {0x0170, "Light Block"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0171, {0x0171, "Dark Block"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0172, {0x0172, "Freikugel"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0173, {0x0173, "Gaea Rage"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0174, {0x0174, "Javelin Rain "}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0175, {0x0175, "Deadly Fury"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0176, {0x0176, "Chaotic Will"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x017A, {0x017A, "Madness Glint"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x017B, {0x017B, "Panta Span"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x017C, {0x017C, "Magatsuhi Harvest"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x017D, {0x017D, "Dia"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x017E, {0x017E, "Diarama"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x017F, {0x017F, "Media "}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0180, {0x0180, "Mediarama"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0181, {0x0181, "Dia"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0182, {0x0182, "Diarama"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0184, {0x0184, "Violent Rage"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0185, {0x0185, "Pandemonic Crush"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0186, {0x0186, "Evil Gleam"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0188, {0x0188, "Sonic Boom"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x018A, {0x018A, "Gaea Rage"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x018B, {0x018B, "Chaotic Will"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x018D, {0x018D, "Javelin Rain "}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x018E, {0x018E, "Deadly Fury"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0191, {0x0191, "Resist Phys"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0192, {0x0192, "Null Phys"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0193, {0x0193, "Drain Phys"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0194, {0x0194, "Repel Phys"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0195, {0x0195, "Resist Fire"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0196, {0x0196, "Null Fire"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0197, {0x0197, "Drain Fire"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0198, {0x0198, "Repel Fire"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x0199, {0x0199, "Resist Ice"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x019A, {0x019A, "Null Ice"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x019B, {0x019B, "Drain Ice"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x019C, {0x019C, "Repel Ice"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x019D, {0x019D, "Resist Elec"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x019E, {0x019E, "Null Elec"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x019F, {0x019F, "Drain Elec"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01A0, {0x01A0, "Repel Elec"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01A1, {0x01A1, "Resist Force"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01A2, {0x01A2, "Null Force"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01A3, {0x01A3, "Drain Force"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01A4, {0x01A4, "Repel Force"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01A5, {0x01A5, "Resist Dark"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01A6, {0x01A6, "Null Dark"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01A7, {0x01A7, "Drain Dark"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01A8, {0x01A8, "Repel Dark"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01A9, {0x01A9, "Resist Light"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01AA, {0x01AA, "Null Light"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01AB, {0x01AB, "Drain Light"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01AC, {0x01AC, "Repel Light"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01AD, {0x01AD, "Light Life Aid"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01AE, {0x01AE, "Life Aid"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01AF, {0x01AF, "Light Mana Aid"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01B0, {0x01B0, "Mana Aid"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01B2, {0x01B2, "Counter"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01B3, {0x01B3, "Retaliate"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01B4, {0x01B4, "Heavenly Counter"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01B5, {0x01B5, "Life Spring"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01B6, {0x01B6, "Great Life Spring"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01B7, {0x01B7, "Mana Spring"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01B8, {0x01B8, "Great Mana Spring"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01B9, {0x01B9, "Curse Siphon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01BA, {0x01BA, "Great Curse Siphon"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01BB, {0x01BB, "Endure"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01BC, {0x01BC, "Enduring Soul"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01BF, {0x01BF, "Critical Zealot"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01D0, {0x01D0, "Restore"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01D1, {0x01D1, "High Restore"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01D4, {0x01D4, "Boon Boost"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01D5, {0x01D5, "Boon Boost EX"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01D6, {0x01D6, "Poison Adept"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01D7, {0x01D7, "Poison Master"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01D8, {0x01D8, "Safeguard"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01DA, {0x01DA, "Hellish Mask"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01DB, {0x01DB, "Abyssal Mask"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01DD, {0x01DD, "Inspiring Leader"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01DE, {0x01DE, "Beast Eye"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01DF, {0x01DF, "Dragon Eye"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01E0, {0x01E0, "Bloody Glee"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01E1, {0x01E1, "Murderous Glee"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01E9, {0x01E9, "Phys Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01EA, {0x01EA, "High Plhys Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01EB, {0x01EB, "Fire Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01EC, {0x01EC, "High Fire Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01ED, {0x01ED, "Ice Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01EE, {0x01EE, "High Ice Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01EF, {0x01EF, "Elec Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01F0, {0x01F0, "High Elece Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01F1, {0x01F1, "Force Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01F2, {0x01F2, "High Force Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01F3, {0x01F3, "Heal Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01F4, {0x01F4, "High Heal Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01F5, {0x01F5, "Dark Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01F6, {0x01F6, "High Dark Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01F7, {0x01F7, "Light Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01F8, {0x01F8, "High Light Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01F9, {0x01F9, "Almighty Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01FA, {0x01FA, "High Mighty Pleroma"}));
        skillsDatabase.insert(std::make_pair<int, SkillsDBEntry>(0x01FF, {0x01FF, "Lightning Pulse"}));

        for (const auto &entry : skillsDatabase)
            skillList.push_back(entry.second);

        std::sort(skillList.begin(),skillList.end(), [](const SkillsDBEntry &x, const SkillsDBEntry &y){ return (x.name < y.name);});
    }

    
} // namespace editor::save::demon
